# tree-sitter-miniscript

A [Tree-sitter](https://tree-sitter.github.io/) grammar for the MiniScript programming language.

> This parser can be used in editors, code analysis tools, and other applications that leverage Tree-sitter for parsing and syntax highlighting.
